Module os_cmd

Module os_cmd 

Available on crate feature os_cmd only.

Modules

presets
Provides configurable command runners such as CargoDoc and CargoCmd.

Macros

fmt_compact
Creates a CompactString using interpolation of runtime expressions.

Structs

CommandSpawner
CommandSpawner is a small builder that treats an iterator as an argv-like sequence:
DecodedText
Decoded child-process output text, supporting both lossless and lossy UTF-8.
MiniStr
A CompactString is a compact string type that can be used almost anywhere a String or str can be used.
Runner
Command runner with configurable preprocessing and execution strategies

Enums

CommandRepr
Command Representation
RunnerInspection
StdioMode
How to wire a stdio stream for the child process.

Traits

RunnableCommand

Functions

collect_boxed_ministr_slice
iter => Box<[MiniStr]>
collect_raw
Parses raw command string into executable components
cow_str_into_cow_osstr
remove_comments_and_collect
Preprocesses command string by removing comment lines
run
Runs an OS command without capturing stdout/stderr (inherits the parent’s stdio).

Type Aliases

CowOsStrVec