pub struct BuildStd { /* private fields */ }os_cmd only.Expand description
Represents the build options for the standard library components.
By default (BuildStd::default()), all options are set to false.
Note: BuildStd.build_default is NOT equivalent to
BuildStd::default()
-
Special Option:
build_default: When set totrue=>["-Z", "build-std"], which compilescore,std,alloc, andproc_macro.- Note: Other options will override
build_default- When
build_defaultis true andcoreis also true, =>["-Z", "build-std=core"] - Only when
build_defaultis true and all other options are false, =>["-Z", "build-std"]
- When
- Note: Other options will override
-
core:true=>["-Z", "build-std=core"] -
alloc:true=>["-Z", "build-std=alloc"] -
When both
coreandallocaretrue=>["-Z", "build-std=core,alloc"]
You can control the components to be compiled using the with_ methods.
Example
use testutils::os_cmd::presets::cargo_build::{ArgConverter, BuildStd};
let build_std_with_core_and_alloc = BuildStd::default()
.with_std(false)
.with_core(true)
.with_alloc(true)
.with_build_default(true);
assert_eq!(
build_std_with_core_and_alloc
.to_args()
.next(),
Some("-Z".into())
);
assert_eq!(
build_std_with_core_and_alloc
.to_args()
.last(),
Some("build-std=core,alloc".into())
);
let build_std_with_default_only = BuildStd::default().with_build_default(true);
assert_eq!(
build_std_with_default_only
.to_args()
.last(),
Some("build-std".into())
);
let build_std_none_enabled = BuildStd::default();
assert_eq!(
build_std_none_enabled
.to_args()
.next(),
None
);Implementations
Sourceimpl BuildStd
impl BuildStd
pub fn with_build_default(self, val: bool) -> Self
pub fn with_std(self, val: bool) -> Self
pub fn with_core(self, val: bool) -> Self
pub fn with_alloc(self, val: bool) -> Self
pub fn with_panic_abort(self, val: bool) -> Self
pub fn with_panic_unwind(self, val: bool) -> Self
pub fn with_test(self, val: bool) -> Self
pub fn with_proc_macro(self, val: bool) -> Self
Sourceimpl BuildStd
impl BuildStd
pub fn get_build_default(&self) -> bool
pub fn get_std(&self) -> bool
pub fn get_core(&self) -> bool
pub fn get_alloc(&self) -> bool
pub fn get_panic_abort(&self) -> bool
pub fn get_panic_unwind(&self) -> bool
pub fn get_test(&self) -> bool
pub fn get_proc_macro(&self) -> bool