BufStderr

Type Alias BufStderr 

pub type BufStderr = BufWriter<StderrLock<'static>>;
Available on crate features print_ext and std only.
A buffered, locked handle to standard error.

Like BufStdout, this holds a lock guard for the lifetime of the value and buffers writes until the buffer is flushed/dropped.

Aliased Type

pub struct BufStderr { /* private fields */ }