Available on crate feature
os_cmd only.Modules
- presets
- Provides configurable command runners such as
CargoDocandCargoCmd.
Macros
- fmt_
compact - Creates a
CompactStringusing interpolation of runtime expressions.
Structs
- Command
Spawner CommandSpawneris a small builder that treats an iterator as anargv-like sequence:- Decoded
Text - Decoded child-process output text, supporting both lossless and lossy UTF-8.
- MiniStr
- A
CompactStringis a compact string type that can be used almost anywhere aStringorstrcan be used. - Runner
- Command runner with configurable preprocessing and execution strategies
Enums
- Command
Repr - Command Representation
- Runner
Inspection - Stdio
Mode - How to wire a stdio stream for the child process.
Traits
Functions
- collect_
boxed_ ministr_ slice - iter =>
Box<[MiniStr]> - collect_
raw - Parses raw command string into executable components
- cow_
str_ into_ cow_ osstr - remove_
comments_ and_ collect - Preprocesses command string by removing comment lines
- run
- Runs an OS command without capturing stdout/stderr (inherits the parent’s stdio).